﻿using Microsoft.Office.Interop.Outlook;

namespace TestProject
{
    /// <summary>
    /// MAPI 폴더 확장
    /// </summary>
    public static class MAPIFolderExtensions
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 폴더 소유 여부 구하기 - HasFolder(rootFolder, targetFolderName)

        /// <summary>
        /// 폴더 소유 여부 구하기
        /// </summary>
        /// <param name="rootFolder">루트 폴더</param>
        /// <param name="targetFolderName">타겟 폴더명</param>
        /// <returns>폴더 소유 여부</returns>
        public static bool HasFolder(this MAPIFolder rootFolder, string targetFolderName)
        {
            foreach(Folder folder in rootFolder.Folders)
            {
                if(folder.Name == targetFolderName)
                {
                    return true;
                }
            }

            return false;
        }

        #endregion
        #region 폴더 구하기 - GetFolder(rootFolder, targetFolderName)

        /// <summary>
        /// 폴더 구하기
        /// </summary>
        /// <param name="rootFolder">루트 폴더</param>
        /// <param name="targetFolderName">타겟 폴더명</param>
        /// <returns>폴더</returns>
        public static Folder GetFolder(this MAPIFolder rootFolder, string targetFolderName)
        {
            foreach(Folder folder in rootFolder.Folders)
            {
                if(folder.Name == targetFolderName)
                {
                    return folder;
                }
            }

            return null;
        }

        #endregion
        #region 폴더 추가하기 - AddFolder(parentFolder, folderName)

        /// <summary>
        /// 폴더 추가하기
        /// </summary>
        /// <param name="parentFolder">부모 폴더</param>
        /// <param name="folderName">폴더명</param>
        /// <returns>MAPI 폴더</returns>
        public static MAPIFolder AddFolder(this MAPIFolder parentFolder, string folderName)
        {
            MAPIFolder folder = parentFolder.Folders.Add(folderName, OlDefaultFolders.olFolderInbox);

            return folder;
        }

        #endregion
    }
}